@@ -2,9 +2,9 @@ import os
 import shutil
 from base64 import b64encode
 
-from ..version import __version__
 from .. import helper
 from ..MetaObject import MetaObject
+from ..version import __version__
 
 
 class Configuration803(MetaObject):
@@ -32,6 +32,7 @@ class Configuration803(MetaObject):
     def __init__(self):
         super(Configuration803, self).__init__()
         self.counter = {}
+        self.product = None
 
     @classmethod
     def decode(cls, src_dir, dest_dir, *, version=None):
@@ -97,7 +98,7 @@ class Configuration803(MetaObject):
         self._encode_info(src_dir, file_name, dest_dir)
         self.write_encode_code(dest_dir)
         helper.json_write(self.header['data'], dest_dir, f'{self.header["file_uuid"]}.json')
-        tasks = self.encode_includes(src_dir, dest_dir)
+        tasks = self.encode_includes(src_dir, file_name, dest_dir, version)
         return tasks
 
     def encode_version(self):
