@@ -233,6 +233,8 @@ def check_version(v8_version: str, src_version: str) -> None:
 
 
 def get_descent_file_name(file_name, descent):
+    if not descent:
+        return file_name
     name: list = file_name.split('.')
     name.insert(-1, str(descent))
     return '.'.join(name)
@@ -253,9 +255,12 @@ def get_near_descent_file_name(path, file_name, descent):
     for entity in entities:
         if entity.startswith(startswith) and entity.endswith(endswith):
             _entity = entity.split('.')
-            if len(_entity) - 1 != size:
+            if entity == file_name:
                 is_without_descent = True
                 continue
+
+            if len(_entity) - 1 != size:
+                continue
             full_path = os.path.join(path, entity)
             if os.path.isfile(full_path):
                 try:
